pub enum ProtocolError<T = Infallible> {
LibraryError(InternalError<T>),
InvalidLoginError,
SerializationError,
ReflectedValueError,
IdentityGroupElementError,
}Expand description
Represents an error in protocol handling
Variants
LibraryError(InternalError<T>)
Internal error encountered
InvalidLoginError
Error in validating credentials
SerializationError
Error with serializing / deserializing protocol messages
ReflectedValueError
This error occurs when the client detects that the server has reflected the OPRF value (beta == alpha)
IdentityGroupElementError
Identity group element was encountered during deserialization, which is invalid
Implementations
Sourceimpl ProtocolError
impl ProtocolError
Sourcepub fn into_custom<T>(self) -> ProtocolError<T>
pub fn into_custom<T>(self) -> ProtocolError<T>
Convert ProtocolError<Infallible> into ProtocolError<T>